// Получаем ссылку на элементы дропзоны, поля для выбора файла и контейнера для миниатюр
const dropZone = document.getElementById('drop-zone');
const fileInput = document.getElementById('file-input');
const thumbnailsContainer = document.getElementById('thumbnails');

// Обработчик события dragover для дропзоны
dropZone.addEventListener('dragover', (e) => {
    e.preventDefault(); // Отменяем стандартное действие браузера
    dropZone.classList.add('dragged'); // Добавляем класс для стилизации
});

// Обработчик события dragleave для дропзоны
dropZone.addEventListener('dragleave', () => {
    dropZone.classList.remove('dragged'); // Удаляем класс для стилизации
});

// Обработчик события drop для дропзоны
dropZone.addEventListener('drop', (e) => {
    e.preventDefault(); // Отменяем стандартное действие браузера
    dropZone.classList.remove('dragged'); // Удаляем класс для стилизации

    // Получаем выбранные файлы
    const files = e.dataTransfer.files;
    if (files.length > 0) {
        fileInput.files = files; // Заполняем поле ввода файлами
        handleFiles(files); // Обрабатываем выбранные файлы
    }
});

// Обработчик события change для поля выбора файла
fileInput.addEventListener('change', () => {
    const files = fileInput.files; // Получаем выбранные файлы
    handleFiles(files); // Обрабатываем выбранные файлы
});

// Функция для обработки выбранных файлов
function handleFiles(files) {
    thumbnailsContainer.innerHTML = ''; // Очищаем контейнер миниатюр

    // Создаем миниатюры для каждого файла
    for (const file of files) {
        const thumbnail = document.createElement('div');
        thumbnail.classList.add('thumbnail');

        const img = document.createElement('img');
        img.src = URL.createObjectURL(file); // Устанавливаем источник изображения
        img.onload = () => URL.revokeObjectURL(img.src); // Очищаем URL после загрузки

        // Создаем кнопку удаления и добавляем обработчик события клика
        const removeButton = document.createElement('button');
        removeButton.textContent = 'X';
        removeButton.classList.add('remove-button');
        removeButton.addEventListener('click', () => {
            thumbnail.remove(); // Удаляем миниатюру
            updateFileInput(); // Обновляем список файлов в поле ввода
        });

        // Добавляем изображение и кнопку удаления в миниатюру
        thumbnail.appendChild(img);
        thumbnail.appendChild(removeButton);

        // Добавляем миниатюру в контейнер
        thumbnailsContainer.appendChild(thumbnail);
    }
}

// Функция для обновления списка файлов в поле ввода
function updateFileInput() {
    const files = [];
    // Получаем список файлов из миниатюр и добавляем в массив
    thumbnailsContainer.querySelectorAll('.thumbnail img').forEach(img => {
        files.push(img.file);
    });
    // Создаем объект FileList из массива файлов и присваиваем его полю ввода
    fileInput.files = new FileListFromArray(files);
}

// Функция для создания объекта FileList из массива файлов
function FileListFromArray(array) {
    let fileList = [];
    // Добавляем каждый файл из массива в список файлов
    array.forEach(file => {
        fileList.push(file);
    });
    // Возвращаем объект DataTransfer, содержащий список файлов
    return new DataTransfer({ items: fileList });
}